@@ -2,7 +2,7 @@ package Mojolicious::Plugin::RoutesAuthDBI;
 use Mojo::Base 'Mojolicious::Plugin::Authentication';
 use Mojo::Loader qw(load_class);
 
-our $VERSION = '0.401';
+our $VERSION = '0.410';
 
 my $access;# 
 my $pkg = __PACKAGE__;
@@ -19,7 +19,7 @@ my $fail_access_cb = sub {
     $c->dumper($args) =~ s/\s+//gr,
     $c->dumper($route->pattern->defaults) =~ s/\s+//gr,
   );
-  $c->render(format=>'txt', text=>"You don`t have access on this route(url)!!!\n");
+  $c->render(format=>'txt', text=>"You don`t have access on this route (url, action) !!!\n");
   
 };
 
@@ -54,6 +54,7 @@ sub register {
     $conf->{admin}{namespace} ||= $pkg;
     $conf->{admin}{controller} ||= 'Admin';
     $conf->{admin}{dbh} = $conf->{dbh};
+    $conf->{admin}{sth} = $access->{sth};
     $conf->{admin}{prefix} ||= lc($conf->{admin}{controller});
     $conf->{admin}{trust} ||= $app->secrets->[0];
     my $admin ||= $self->admin_controller($app, $conf->{admin});
@@ -215,11 +216,11 @@ sub access {# add_condition
 
 =head1 NAME
 
-Mojolicious::Plugin::RoutesAuthDBI - Generate routes from sql-table, make authentication and make restrict access (authorization) to route with users/roles tables. Plugin makes an auth operations throught the plugin L<Mojolicious::Plugin::Authentication> on which is based.
+Mojolicious::Plugin::RoutesAuthDBI - from DBI sql-tables does generate routes, make authentication and make restrict access (authorization) to request. Plugin makes an auth operations throught the plugin L<Mojolicious::Plugin::Authentication> on which is based.
 
 =head1 DB DESIGN DIAGRAM
 
-First of all see L<SVG|https://github.com/mche/Mojolicious-Plugin-RoutesAuthDBI/blob/master/Diagram.svg>  or L<PNG|http://i.imgur.com/CwqiB4f.png>
+First of all you will see L<SVG|https://github.com/mche/Mojolicious-Plugin-RoutesAuthDBI/blob/master/Diagram.svg>  or L<PNG|http://i.imgur.com/CwqiB4f.png>
 
 =head1 SYNOPSIS
 
@@ -353,7 +354,7 @@ L<Mojolicious::Plugin::Authorization>
 
 =head1 AUTHOR
 
-Михаил Че (Mikhail Che), C<< <mche [on] cpan.org> >>
+Михаил Че (Mikhail Che), C<< <mche[-at-]cpan.org> >>
 
 =head1 BUGS / CONTRIBUTING
 
