@@ -1,8 +1,8 @@
 package Mojolicious::Plugin::RoutesAuthDBI::Install;
 use Mojo::Base 'Mojolicious::Controller';
-use DBIx::POS;
+use DBIx::POS::Template;
 
-my $sql = DBIx::POS->instance(__FILE__);
+my $sql = DBIx::POS::Template->new(__FILE__, enc => 'utf8');
 
 =pod
 
@@ -10,7 +10,7 @@ my $sql = DBIx::POS->instance(__FILE__);
 
 =head3 Warn
 
-B<POD ERRORS> here is normal because DBIx::POS used.
+B<POD ERRORS> here is normal because DBIx::POS::Template used.
 
 =head1 Mojolicious::Plugin::RoutesAuthDBI::Install
 
@@ -156,7 +156,7 @@ TXT
 
 =name schema.sequence
 
-=desc
+=desc последовательность
 
 =sql
 
@@ -277,29 +277,14 @@ TXT
 
 =back
 
-=head1 Drop schema
-
-=name schema.drop
-
-=desc
-
-=sql
-
-    drop table refs;
-    drop table users;
-    drop table roles;
-    drop table routes;
-    drop table controllers;
-    drop table actions;
-    drop table namespaces;
-    drop sequence ID;
-
 =cut
 
+
 sub schema {
   my $c = shift;
   #~ $c->render(format=>'txt', text => join '', <Mojolicious::Plugin::RoutesAuthDBI::Install::DATA>);
   $c->render(format=>'txt', text => <<TXT);
+
 $sql->{'schema.sequence'}
 
 $sql->{'schema.routes'}
@@ -319,6 +304,35 @@ $sql->{'schema.refs'}
 TXT
 }
 
+=pod
+
+=head1 Drop schema
+
+=name schema.drop
+
+=desc
+
+=sql
+
+    drop table refs;
+    drop table users;
+    drop table roles;
+    drop table routes;
+    drop table controllers;
+    drop table actions;
+    drop table namespaces;
+    drop sequence ID;
+
+=name схема
+
+=desc
+
+=sql
+
+    123
+
+=cut
+
 sub schema_drop {
   my $c = shift;
   
